@@ -36,8 +36,6 @@
 #include <string.h>
 #endif
 
-#include <gdk/gdkkeysyms.h>
-
 #include "thunar/thunar-gobject-extensions.h"
 #include "thunar/thunar-icon-factory.h"
 #include "thunar/thunar-icon-renderer.h"
@@ -48,6 +46,8 @@
 #include "thunar/thunar-util.h"
 #include "thunar/thunar-window.h"
 
+#include <gdk/gdkkeysyms.h>
+
 
 
 #define ICON_MARGIN (2)
@@ -62,66 +62,85 @@ enum
 
 
 
-static void     thunar_path_entry_editable_init                 (GtkEditableInterface *iface);
-static void     thunar_path_entry_finalize                      (GObject              *object);
-static void     thunar_path_entry_get_property                  (GObject              *object,
-                                                                 guint                 prop_id,
-                                                                 GValue               *value,
-                                                                 GParamSpec           *pspec);
-static void     thunar_path_entry_set_property                  (GObject              *object,
-                                                                 guint                 prop_id,
-                                                                 const GValue         *value,
-                                                                 GParamSpec           *pspec);
-static gboolean thunar_path_entry_focus                         (GtkWidget            *widget,
-                                                                 GtkDirectionType      direction);
-static void     thunar_path_entry_icon_press_event              (GtkEntry            *entry,
-                                                                 GtkEntryIconPosition icon_pos,
-                                                                 GdkEventButton      *event,
-                                                                 gpointer             userdata);
-static void     thunar_path_entry_icon_release_event            (GtkEntry            *entry,
-                                                                 GtkEntryIconPosition icon_pos,
-                                                                 GdkEventButton      *event,
-                                                                 gpointer             user_data);
-static void     thunar_path_entry_scale_changed                 (GObject              *object,
-                                                                 GParamSpec           *pspec,
-                                                                 gpointer              user_data);
-static gboolean thunar_path_entry_motion_notify_event           (GtkWidget            *widget,
-                                                                 GdkEventMotion       *event);
-static gboolean thunar_path_entry_key_press_event               (GtkWidget            *widget,
-                                                                 GdkEventKey          *event);
-static void     thunar_path_entry_drag_data_get                 (GtkWidget            *widget,
-                                                                 GdkDragContext       *context,
-                                                                 GtkSelectionData     *selection_data,
-                                                                 guint                 info,
-                                                                 guint                 timestamp);
-static void     thunar_path_entry_activate                      (GtkEntry             *entry);
-static void     thunar_path_entry_changed                       (GtkEditable          *editable);
-static void     thunar_path_entry_update_icon                   (ThunarPathEntry      *path_entry);
-static void     thunar_path_entry_do_insert_text                (GtkEditable          *editable,
-                                                                 const gchar          *new_text,
-                                                                 gint                  new_text_length,
-                                                                 gint                 *position);
-static void     thunar_path_entry_clear_completion              (ThunarPathEntry      *path_entry);
-static void     thunar_path_entry_common_prefix_append          (ThunarPathEntry      *path_entry,
-                                                                 gboolean              highlight);
-static void     thunar_path_entry_common_prefix_lookup          (ThunarPathEntry      *path_entry,
-                                                                 gchar               **prefix_return,
-                                                                 ThunarFile          **file_return);
-static gboolean thunar_path_entry_match_func                    (GtkEntryCompletion   *completion,
-                                                                 const gchar          *key,
-                                                                 GtkTreeIter          *iter,
-                                                                 gpointer              user_data);
-static gboolean thunar_path_entry_match_selected                (GtkEntryCompletion   *completion,
-                                                                 GtkTreeModel         *model,
-                                                                 GtkTreeIter          *iter,
-                                                                 gpointer              user_data);
-static gboolean thunar_path_entry_parse                         (ThunarPathEntry      *path_entry,
-                                                                 gchar               **folder_part,
-                                                                 gchar               **file_part,
-                                                                 GError              **error);
-static void     thunar_path_entry_queue_check_completion        (ThunarPathEntry      *path_entry);
-static gboolean thunar_path_entry_check_completion_idle         (gpointer              user_data);
-static void     thunar_path_entry_check_completion_idle_destroy (gpointer              user_data);
+static void
+thunar_path_entry_editable_init (GtkEditableInterface *iface);
+static void
+thunar_path_entry_finalize (GObject *object);
+static void
+thunar_path_entry_get_property (GObject    *object,
+                                guint       prop_id,
+                                GValue     *value,
+                                GParamSpec *pspec);
+static void
+thunar_path_entry_set_property (GObject      *object,
+                                guint         prop_id,
+                                const GValue *value,
+                                GParamSpec   *pspec);
+static gboolean
+thunar_path_entry_focus (GtkWidget       *widget,
+                         GtkDirectionType direction);
+static gboolean
+thunar_path_entry_icon_press_event (GtkEntry            *entry,
+                                    GtkEntryIconPosition icon_pos,
+                                    GdkEventButton      *event,
+                                    gpointer             userdata);
+static void
+thunar_path_entry_scale_changed (GObject    *object,
+                                 GParamSpec *pspec,
+                                 gpointer    user_data);
+static gboolean
+thunar_path_entry_key_press_event (GtkWidget   *widget,
+                                   GdkEventKey *event);
+static void
+thunar_path_entry_drag_data_get (GtkWidget        *widget,
+                                 GdkDragContext   *context,
+                                 GtkSelectionData *selection_data,
+                                 guint             info,
+                                 guint             timestamp);
+static void
+thunar_path_entry_drag_end (GtkWidget      *widget,
+                            GdkDragContext *context);
+static void
+thunar_path_entry_activate (GtkEntry *entry);
+static void
+thunar_path_entry_changed (GtkEditable *editable);
+static void
+thunar_path_entry_update_icon (ThunarPathEntry *path_entry);
+static void
+thunar_path_entry_do_insert_text (GtkEditable *editable,
+                                  const gchar *new_text,
+                                  gint         new_text_length,
+                                  gint        *position);
+static void
+thunar_path_entry_clear_completion (ThunarPathEntry *path_entry);
+static void
+thunar_path_entry_common_prefix_append (ThunarPathEntry *path_entry,
+                                        gboolean         highlight);
+static void
+thunar_path_entry_common_prefix_lookup (ThunarPathEntry *path_entry,
+                                        gchar          **prefix_return,
+                                        ThunarFile     **file_return);
+static gboolean
+thunar_path_entry_match_func (GtkEntryCompletion *completion,
+                              const gchar        *key,
+                              GtkTreeIter        *iter,
+                              gpointer            user_data);
+static gboolean
+thunar_path_entry_match_selected (GtkEntryCompletion *completion,
+                                  GtkTreeModel       *model,
+                                  GtkTreeIter        *iter,
+                                  gpointer            user_data);
+static gboolean
+thunar_path_entry_parse (ThunarPathEntry *path_entry,
+                         gchar          **folder_part,
+                         gchar          **file_part,
+                         GError         **error);
+static void
+thunar_path_entry_queue_check_completion (ThunarPathEntry *path_entry);
+static gboolean
+thunar_path_entry_check_completion_idle (gpointer user_data);
+static void
+thunar_path_entry_check_completion_idle_destroy (gpointer user_data);
 
 
 
@@ -139,23 +158,24 @@ struct _ThunarPathEntry
   ThunarFile        *current_file;
   GFile             *working_directory;
 
-  guint              drag_button;
-  gint               drag_x;
-  gint               drag_y;
+  guint drag_button;
 
   /* auto completion support */
-  guint              in_change : 1;
-  guint              has_completion : 1;
-  guint              check_completion_idle_id;
+  guint in_change : 1;
+  guint has_completion : 1;
+  guint check_completion_idle_id;
 
-  gboolean           search_mode;
+  gboolean search_mode;
 };
 
 
 
-static const GtkTargetEntry drag_targets[] =
-{
-  { "text/uri-list", 0, 0, },
+static const GtkTargetEntry drag_targets[] = {
+  {
+  "text/uri-list",
+  0,
+  0,
+  },
 };
 
 
@@ -183,8 +203,8 @@ thunar_path_entry_class_init (ThunarPathEntryClass *klass)
 
   gtkwidget_class = GTK_WIDGET_CLASS (klass);
   gtkwidget_class->focus = thunar_path_entry_focus;
-  gtkwidget_class->motion_notify_event = thunar_path_entry_motion_notify_event;
   gtkwidget_class->drag_data_get = thunar_path_entry_drag_data_get;
+  gtkwidget_class->drag_end = thunar_path_entry_drag_end;
 
   gtkentry_class = GTK_ENTRY_CLASS (klass);
   gtkentry_class->activate = thunar_path_entry_activate;
@@ -210,7 +230,7 @@ thunar_path_entry_class_init (ThunarPathEntryClass *klass)
   gtk_widget_class_install_style_property (gtkwidget_class,
                                            g_param_spec_int ("icon-size",
                                                              _("Icon size"),
-                                                             _("The icon size for the path entry"),
+                                                               _("The icon size for the path entry"),
                                                              1, G_MAXINT, 16, EXO_PARAM_READABLE));
 }
 
@@ -230,8 +250,8 @@ thunar_path_entry_editable_init (GtkEditableInterface *iface)
 static void
 thunar_path_entry_init (ThunarPathEntry *path_entry)
 {
-  GtkEntryCompletion *completion;
-  GtkCellRenderer    *renderer;
+  GtkEntryCompletion      *completion;
+  GtkCellRenderer         *renderer;
   ThunarStandardViewModel *store;
 
   path_entry->check_completion_idle_id = 0;
@@ -279,7 +299,6 @@ thunar_path_entry_init (ThunarPathEntry *path_entry)
 
   /* connect the icon signals */
   g_signal_connect (G_OBJECT (path_entry), "icon-press", G_CALLBACK (thunar_path_entry_icon_press_event), NULL);
-  g_signal_connect (G_OBJECT (path_entry), "icon-release", G_CALLBACK (thunar_path_entry_icon_release_event), NULL);
   g_signal_connect (G_OBJECT (path_entry), "notify::scale-factor", G_CALLBACK (thunar_path_entry_scale_changed), NULL);
 
   /* disabled initially */
@@ -394,42 +413,6 @@ thunar_path_entry_focus (GtkWidget       *widget,
 
 
 
-static void
-thunar_path_entry_icon_press_event (GtkEntry            *entry,
-                                    GtkEntryIconPosition icon_pos,
-                                    GdkEventButton      *event,
-                                    gpointer             userdata)
-{
-  ThunarPathEntry *path_entry = THUNAR_PATH_ENTRY (entry);
-
-  if (event->button == 1 && icon_pos == GTK_ENTRY_ICON_PRIMARY)
-    {
-      /* consume the event */
-      path_entry->drag_button = event->button;
-      path_entry->drag_x = event->x;
-      path_entry->drag_y = event->y;
-    }
-}
-
-
-
-static void
-thunar_path_entry_icon_release_event (GtkEntry            *entry,
-                                      GtkEntryIconPosition icon_pos,
-                                      GdkEventButton      *event,
-                                      gpointer             user_data)
-{
-  ThunarPathEntry *path_entry = THUNAR_PATH_ENTRY (entry);
-
-  if (event->button == path_entry->drag_button && icon_pos == GTK_ENTRY_ICON_PRIMARY)
-    {
-      /* reset the drag button state */
-      path_entry->drag_button = 0;
-    }
-}
-
-
-
 static void
 thunar_path_entry_scale_changed (GObject    *object,
                                  GParamSpec *pspec,
@@ -441,10 +424,12 @@ thunar_path_entry_scale_changed (GObject    *object,
 
 
 static gboolean
-thunar_path_entry_motion_notify_event (GtkWidget      *widget,
-                                       GdkEventMotion *event)
+thunar_path_entry_icon_press_event (GtkEntry            *entry,
+                                    GtkEntryIconPosition icon_pos,
+                                    GdkEventButton      *event,
+                                    gpointer             user_data)
 {
-  ThunarPathEntry *path_entry = THUNAR_PATH_ENTRY (widget);
+  ThunarPathEntry *path_entry = THUNAR_PATH_ENTRY (entry);
   GdkDragContext  *context;
   GtkTargetList   *target_list;
   GdkPixbuf       *icon;
@@ -452,23 +437,26 @@ thunar_path_entry_motion_notify_event (GtkWidget      *widget,
   gint             size;
   gint             scale_factor;
 
-  if (path_entry->drag_button > 0
-      && path_entry->current_file != NULL
-      /*FIXME && event->window == gtk_entry_get_icon_window (GTK_ENTRY (widget), GTK_ENTRY_ICON_PRIMARY)*/
-      && gtk_drag_check_threshold (widget, path_entry->drag_x, path_entry->drag_y, event->x, event->y))
+  if (path_entry->current_file == NULL)
+    return FALSE;
+
+  if (event->button == 1 && icon_pos == GTK_ENTRY_ICON_PRIMARY)
     {
-      /* create the drag context */
+      /* save the drag button state */
+      path_entry->drag_button = event->button;
+
+      /* create a drag context */
       target_list = gtk_target_list_new (drag_targets, G_N_ELEMENTS (drag_targets));
-      context = gtk_drag_begin_with_coordinates (widget, target_list,
-                                                 GDK_ACTION_COPY |
-                                                 GDK_ACTION_LINK,
-                                                 path_entry->drag_button,
+      context = gtk_drag_begin_with_coordinates (GTK_WIDGET (entry), target_list,
+                                                 GDK_ACTION_COPY | GDK_ACTION_LINK,
+                                                 event->button,
+
                                                  (GdkEvent *) event, -1, -1);
       gtk_target_list_unref (target_list);
 
       /* setup the drag icon (atleast 24px) */
-      gtk_widget_style_get (widget, "icon-size", &size, NULL);
-      scale_factor = gtk_widget_get_scale_factor (widget);
+      gtk_widget_style_get (GTK_WIDGET (entry), "icon-size", &size, NULL);
+      scale_factor = gtk_widget_get_scale_factor (GTK_WIDGET (entry));
       icon = thunar_icon_factory_load_file_icon (path_entry->icon_factory,
                                                  path_entry->current_file,
                                                  THUNAR_FILE_ICON_STATE_DEFAULT,
@@ -476,19 +464,16 @@ thunar_path_entry_motion_notify_event (GtkWidget      *widget,
                                                  FALSE, NULL);
       if (G_LIKELY (icon != NULL))
         {
-          surface = gdk_cairo_surface_create_from_pixbuf (icon, scale_factor, gtk_widget_get_window (widget));
+          surface = gdk_cairo_surface_create_from_pixbuf (icon, scale_factor, gtk_widget_get_window (GTK_WIDGET (entry)));
           g_object_unref (G_OBJECT (icon));
           gtk_drag_set_icon_surface (context, surface);
           cairo_surface_destroy (surface);
         }
 
-      /* reset the drag button state */
-      path_entry->drag_button = 0;
-
       return TRUE;
     }
 
-  return (*GTK_WIDGET_CLASS (thunar_path_entry_parent_class)->motion_notify_event) (widget, event);
+  return FALSE;
 }
 
 
@@ -535,12 +520,12 @@ thunar_path_entry_drag_data_get (GtkWidget        *widget,
                                  guint             info,
                                  guint             timestamp)
 {
-  ThunarPathEntry  *path_entry = THUNAR_PATH_ENTRY (widget);
-  GList             file_list;
-  gchar           **uris;
+  ThunarPathEntry *path_entry = THUNAR_PATH_ENTRY (widget);
+  GList            file_list;
+  gchar          **uris;
 
-  /* verify that we actually display a path */
-  if (G_LIKELY (path_entry->current_file != NULL))
+  /* check if the icon was clicked and verify that we actually display a path */
+  if (path_entry->drag_button > 0 && path_entry->current_file != NULL)
     {
       /* transform the path for the current file into an uri string list */
       file_list.next = file_list.prev = NULL;
@@ -550,7 +535,25 @@ thunar_path_entry_drag_data_get (GtkWidget        *widget,
       uris = thunar_g_file_list_to_stringv (&file_list);
       gtk_selection_data_set_uris (selection_data, uris);
       g_strfreev (uris);
+
+      return;
     }
+
+  (*GTK_WIDGET_CLASS (thunar_path_entry_parent_class)->drag_data_get) (widget, context, selection_data, info, timestamp);
+}
+
+
+
+static void
+thunar_path_entry_drag_end (GtkWidget      *widget,
+                            GdkDragContext *context)
+{
+  ThunarPathEntry *path_entry = THUNAR_PATH_ENTRY (widget);
+
+  /* reset the drag button state */
+  path_entry->drag_button = 0;
+
+  (*GTK_WIDGET_CLASS (thunar_path_entry_parent_class)->drag_end) (widget, context);
 }
 
 
@@ -601,7 +604,8 @@ thunar_path_entry_changed (GtkEditable *editable)
       GtkWidget *window = gtk_widget_get_toplevel (GTK_WIDGET (editable));
       path_entry->search_mode = TRUE;
       update_icon = TRUE;
-      thunar_window_update_search (THUNAR_WINDOW (window));
+      if (GTK_IS_WINDOW (window))
+        thunar_window_update_search (THUNAR_WINDOW (window));
     }
   else
     {
@@ -611,7 +615,7 @@ thunar_path_entry_changed (GtkEditable *editable)
           GtkWidget *window = gtk_widget_get_toplevel (GTK_WIDGET (editable));
           thunar_window_action_cancel_search (THUNAR_WINDOW (window));
         }
-      
+
       /* location/folder-path code */
       scheme = g_uri_parse_scheme (text);
       if (G_UNLIKELY (scheme != NULL))
@@ -892,8 +896,8 @@ static gboolean
 thunar_path_entry_has_prefix_casefolded (const gchar *string,
                                          const gchar *prefix)
 {
-  gchar *string_casefolded;
-  gchar *prefix_casefolded;
+  gchar   *string_casefolded;
+  gchar   *prefix_casefolded;
   gboolean has_prefix;
 
   if (string == NULL || prefix == NULL)
@@ -902,7 +906,7 @@ thunar_path_entry_has_prefix_casefolded (const gchar *string,
   string_casefolded = g_utf8_casefold (string, -1);
   prefix_casefolded = g_utf8_casefold (prefix, -1);
 
-  has_prefix = g_str_has_prefix (string_casefolded , prefix_casefolded);
+  has_prefix = g_str_has_prefix (string_casefolded, prefix_casefolded);
 
   g_free (string_casefolded);
   g_free (prefix_casefolded);
@@ -1225,7 +1229,7 @@ thunar_path_entry_check_completion_idle_destroy (gpointer user_data)
  *
  * Return value: the newly allocated #ThunarPathEntry.
  **/
-GtkWidget*
+GtkWidget *
 thunar_path_entry_new (void)
 {
   return g_object_new (THUNAR_TYPE_PATH_ENTRY, NULL);
@@ -1243,7 +1247,7 @@ thunar_path_entry_new (void)
  *
  * Return value: the #ThunarFile for @path_entry or %NULL.
  **/
-ThunarFile*
+ThunarFile *
 thunar_path_entry_get_current_file (ThunarPathEntry *path_entry)
 {
   _thunar_return_val_if_fail (THUNAR_IS_PATH_ENTRY (path_entry), NULL);
@@ -1264,11 +1268,11 @@ void
 thunar_path_entry_set_current_file (ThunarPathEntry *path_entry,
                                     ThunarFile      *current_file)
 {
-  GFile    *file;
-  gchar    *text;
-  gchar    *unescaped;
-  gchar    *tmp;
-  gboolean  is_uri = FALSE;
+  GFile   *file;
+  gchar   *text;
+  gchar   *unescaped;
+  gchar   *tmp;
+  gboolean is_uri = FALSE;
 
   _thunar_return_if_fail (THUNAR_IS_PATH_ENTRY (path_entry));
   _thunar_return_if_fail (current_file == NULL || THUNAR_IS_FILE (current_file));
@@ -1313,7 +1317,7 @@ thunar_path_entry_set_current_file (ThunarPathEntry *path_entry,
 
       // convert filename into valid UTF-8 string for display
       tmp = text;
-      text = g_filename_display_name(tmp);
+      text = g_filename_display_name (tmp);
       g_free (tmp);
     }
 
@@ -1372,17 +1376,17 @@ thunar_path_entry_set_working_directory (ThunarPathEntry *path_entry,
  *
  * It's the responsibility of the caller to free the returned string using `g_free`.
  **/
-gchar*
+gchar *
 thunar_path_entry_get_search_query (ThunarPathEntry *path_entry)
 {
   unsigned long search_prefix_length;
-  const gchar *text = gtk_entry_get_text (GTK_ENTRY (path_entry));
+  const gchar  *text = gtk_entry_get_text (GTK_ENTRY (path_entry));
   search_prefix_length = strlen (thunar_util_get_search_prefix ());
 
   _thunar_return_val_if_fail (THUNAR_IS_PATH_ENTRY (path_entry), NULL);
   _thunar_return_val_if_fail (strncmp (text, thunar_util_get_search_prefix (), search_prefix_length) == 0, NULL);
 
-  return strlen(text) > search_prefix_length ? g_strdup (&text[search_prefix_length]) : g_strdup ("");
+  return strlen (text) > search_prefix_length ? g_strdup (&text[search_prefix_length]) : g_strdup ("");
 }
 
 
